==> mongodb-js-compass-kpi-usage-0.2.0.tgz: package/lib/launches.js <==
/* eslint-env es6 */

var mixpanel = require('mixpanel-api-wrapper');
var helpers = require('./helpers.js');

var today = helpers.getToday();
var monthAgo = helpers.getMonthAgo();

var launchesByOS = `function main() {
  function getDay(event) {
    return new Date(event.time).toISOString().substr(0, 10);
  }
  return Events({
    from_date: '${helpers.formatDate(monthAgo)}',
    to_date: '${helpers.formatDate(today)}'
  })
  .filter(function(event) {
    return event.name == "App launched";
  })
  .filter(function(event) {
    return /^((?!(dev|world|testing)).)*$/.test(event.properties['app version']);
  })
  .groupBy(['properties.$os', getDay], mixpanel.reducer.count())
  .map(function(item) {
    var obj = {};
    obj[item.key[1]] = {
      version: item.key[0],
      count: item.value
    };
    return obj;
  })
  .reduce(function(accumulators, items) {
    var obj = {};
    var key, i, day;
    for (i = 0; i < accumulators.length; ++i) {
      for (var date in accumulators[i]) {
        if (obj[date] === undefined) {
          obj[date] = {};
        }
        for (var vers in accumulators[i][date]) {
          if (obj[date][vers] === undefined) {
            obj[date][vers] = accumulators[i][date][vers];
          }
          else {
            obj[date][vers] += accumulators[i][date][vers];
          }
        }
      }
    }
    for (i = 0; i < items.length; ++i) {
      day = Object.keys(items[i])[0];
      if (obj[day] === undefined) {
        obj[day] = {};
      }
      if (obj[day][items[i][day]['version']] === undefined) {
        obj[day][items[i][day].version] = items[i][day].count;
      }
      else {
        obj[day][items[i][day].version] += items[i][day].count;
      }
    }
    return obj;
  });
}`;

var launchesByCompassVersion = `function main() {
  function getDay(event) {
    return new Date(event.time).toISOString().substr(0, 10);
  }
  return Events({
    from_date: '${helpers.formatDate(monthAgo)}',
    to_date: '${helpers.formatDate(today)}'
  })
  .filter(function(event) {
    return event.name == "App launched";
  })
  .filter(function(event) {
    return /^((?!(dev|world|testing)).)*$/.test(event.properties['app version']);
  })
  .groupBy(['properties.app version', getDay], mixpanel.reducer.count())
  .map(function(item) {
    var obj = {};
    obj[item.key[1]] = {
      version: item.key[0],
      count: item.value
    };
    return obj;
  })
  .reduce(function(accumulators, items) {
    var obj = {};
    var key, i, day;
    for (i = 0; i < accumulators.length; ++i) {
      for (var date in accumulators[i]) {
        if (obj[date] === undefined) {
          obj[date] = {};
        }
        for (var vers in accumulators[i][date]) {
          if (obj[date][vers] === undefined) {
            obj[date][vers] = accumulators[i][date][vers];
          }
          else {
            obj[date][vers] += accumulators[i][date][vers];
          }
        }
      }
    }
    for (i = 0; i < items.length; ++i) {
      day = Object.keys(items[i])[0];
      if (obj[day] === undefined) {
        obj[day] = {};
      }
      if (obj[day][items[i][day]['version']] === undefined) {
        obj[day][items[i][day].version] = items[i][day].count;
      }
      else {
        obj[day][items[i][day].version] += items[i][day].count;
      }
    }
    return obj;
  });
}`;

function getLaunchesVersionData(secret) {
  var str = mixpanel.mixpanelJQL(secret, launchesByCompassVersion);
  var str2 = helpers.transformStreamJQL(str);
  return str2;
}

function getLaunchesOsData(secret) {
  var str = mixpanel.mixpanelJQL(secret, launchesByOS);
  var str2 = helpers.transformStreamJQL(str);
  return str2;
}

module.exports = {
  getLaunchesOsData: getLaunchesOsData,
  getLaunchesVersionData: getLaunchesVersionData
};

==> mongodb-js-compass-kpi-usage-0.4.0.tgz: package/lib/launches.js <==
/* eslint-env es6 */

var mixpanel = require('mixpanel-api-wrapper');
var helpers = require('./helpers.js');

var yesterday = helpers.getYesterday();
var monthAgo = helpers.getMonthAgo();

/**
 * JQL query to grab app launches by OS version. Query returns object
 * in the form:
 * {
 *  '2016-08-02': {
 *        Mac OS X: 11,
 *        Windows: 12
 *    },
 *  '2016-08-01': {
 *        Mac OS X: 10,
 *        Windows: 5
 *    }
 * }
*/
var launchesByOS = `function main() {
  function getDay(event) {
    return new Date(event.time).toISOString().substr(0, 10);
  }
  return Events({
    from_date: '${helpers.formatDate(monthAgo)}',
    to_date: '${helpers.formatDate(yesterday)}'
  })
  .filter(function(event) {
    return event.name == "App launched";
  })
  .filter(function(event) {
    return /^((?!(dev|world|testing)).)*$/.test(event.properties['app version']);
  })
  .groupBy(['properties.$os', getDay], mixpanel.reducer.count())
  .map(function(item) {
    var obj = {};
    obj[item.key[1]] = {
      version: item.key[0],
      count: item.value
    };
    return obj;
  })
  .reduce(function(accumulators, items) {
    var obj = {};
    var key, i, day;
    for (i = 0; i < accumulators.length; ++i) {
      for (var date in accumulators[i]) {
        if (obj[date] === undefined) {
          obj[date] = {};
        }
        for (var vers in accumulators[i][date]) {
          if (obj[date][vers] === undefined) {
            obj[date][vers] = accumulators[i][date][vers];
          }
          else {
            obj[date][vers] += accumulators[i][date][vers];
          }
        }
      }
    }
    for (i = 0; i < items.length; ++i) {
      day = Object.keys(items[i])[0];
      if (obj[day] === undefined) {
        obj[day] = {};
      }
      if (obj[day][items[i][day]['version']] === undefined) {
        obj[day][items[i][day].version] = items[i][day].count;
      }
      else {
        obj[day][items[i][day].version] += items[i][day].count;
      }
    }
    return obj;
  });
}`;

/**
 * JQL query to grab app launches by OS version. Query returns object
 * in the form:
 * {
 *  '2016-08-02': {
 *        1.1.5: 11,
 *        1.3.0-beta.2: 12
 *    },
 *  '2016-08-01': {
 *        1.2.0: 10,
 *        1.3.0-beta.3: 5
 *    }
 * }
*/
var launchesByCompassVersion = `function main() {
  function getDay(event) {
    return new Date(event.time).toISOString().substr(0, 10);
  }
  return Events({
    from_date: '${helpers.formatDate(monthAgo)}',
    to_date: '${helpers.formatDate(yesterday)}'
  })
  .filter(function(event) {
    return event.name == "App launched";
  })
  .filter(function(event) {
    return /^((?!(dev|world|testing)).)*$/.test(event.properties['app version']);
  })
  .groupBy(['properties.app version', getDay], mixpanel.reducer.count())
  .map(function(item) {
    var obj = {};
    obj[item.key[1]] = {
      version: item.key[0],
      count: item.value
    };
    return obj;
  })
  .reduce(function(accumulators, items) {
    var obj = {};
    var key, i, day;
    for (i = 0; i < accumulators.length; ++i) {
      for (var date in accumulators[i]) {
        if (obj[date] === undefined) {
          obj[date] = {};
        }
        for (var vers in accumulators[i][date]) {
          if (obj[date][vers] === undefined) {
            obj[date][vers] = accumulators[i][date][vers];
          }
          else {
            obj[date][vers] += accumulators[i][date][vers];
          }
        }
      }
    }
    for (i = 0; i < items.length; ++i) {
      day = Object.keys(items[i])[0];
      if (obj[day] === undefined) {
        obj[day] = {};
      }
      if (obj[day][items[i][day]['version']] === undefined) {
        obj[day][items[i][day].version] = items[i][day].count;
      }
      else {
        obj[day][items[i][day].version] += items[i][day].count;
      }
    }
    return obj;
  });
}`;

/**
 * Function that gets app launches per Compass version by day. Bulk of the
 * logic occurs in above JQL query.
 * @param {string} mixpanelAPISecret      Mixpanel API secret to access team's data
 * @return {stream}                       returns stream of results from Mixpanel API
*/
function getLaunchesVersionData(mixpanelAPISecret) {
  var stream = mixpanel.mixpanelJQL(mixpanelAPISecret, launchesByCompassVersion);
  var transformedStream = helpers.transformStreamJQL(stream);
  return transformedStream;
}

/**
 * Function that gets app launches by OS type by day. Bulk of the
 * logic occurs in above JQL query.
 * @param {string} mixpanelAPISecret      Mixpanel API secret to access team's data
 * @return {stream}                       returns stream of results from Mixpanel API
*/
function getLaunchesOsData(mixpanelAPISecret) {
  var stream = mixpanel.mixpanelJQL(mixpanelAPISecret, launchesByOS);
  var transformedStream = helpers.transformStreamJQL(stream);
  return transformedStream;
}

module.exports = {
  getLaunchesOsData: getLaunchesOsData,
  getLaunchesVersionData: getLaunchesVersionData
};
